@@ -57,8 +57,8 @@ class TerminalAPI:
         result = self.search_terminal(sn_name_tid=serial_number, include_installed_apks=include_installed_apks, include_installed_firmwares=include_installed_firmwares, include_detail_info=include_detail_info, include_geolocation=include_geolocation)
         if result is not None and "dataset" in result and len(result['dataset']) > 0:
             result = result['dataset'][0]
-            #if "id" in result and include_detail_info:
-                #result = self.get_terminal(result["id"], include_detail_info = include_detail_info, include_installed_apks = include_installed_apks, include_installed_firmwares = include_installed_firmwares, include_geolocation = include_geolocation)
+            if "id" in result and include_detail_info:
+                result = self.get_terminal(result["id"], include_detail_info = include_detail_info, include_installed_apks = include_installed_apks, include_installed_firmwares = include_installed_firmwares, include_geolocation = include_geolocation)
             return result
         else:
             return None
@@ -79,7 +79,7 @@ class TerminalAPI:
     def get_terminal_id_using_sn(self, serial_number, include_installed_apks = False, include_installed_firmwares = False, include_detail_info = False, include_geolocation = False):
         result = self.search_terminal(sn_name_tid=serial_number, include_installed_apks = include_installed_apks, include_installed_firmwares = include_installed_firmwares, include_detail_info = include_detail_info, include_geolocation = include_geolocation)
         if result is not None and "dataset" in result and len(result['dataset']) > 0:
-            result = result['dataset'][0]
+            result = result['dataset'][0]            
             return result['id']
         else:
             return None
